import multer from "multer";

function configureStorage(folder) {
  return multer.diskStorage({
    destination: function (req, file, cb) {
      cb(null, folder);
    },
    filename: function (req, file, cb) {
      const uniqueSuffix = Date.now() + "-" + Math.round(Math.random() * 1e9);
      const originalName = file.originalname;
      const extension = originalName.substring(originalName.lastIndexOf("."));
      cb(null, uniqueSuffix + extension);
    },
  });
}

function configureStorageForInputFile(folder) {
  return multer.diskStorage({
    destination: function (req, file, cb) {
      cb(null, folder);
    },
    filename: function (req, file, cb) {
      cb(null, file.originalname); // Date.now()
    },
  });
}

export function uploadSingle(folder, keyName) {
  return multer({ storage: configureStorage(folder) }).single(keyName);
}

export function uploadMultiple(folder, keyName, maxCount) {
  return multer({ storage: configureStorage(folder) }).array(keyName, maxCount);
}

export function uploadMultipleFile(folder, keyName, maxCount) {
  return multer({
    storage: configureStorageForInputFile(folder),
    limits: {
      fileSize: 1024 * 1024 * 200, // 200MB size limit for each file
    },
  }).array(keyName, maxCount);
}
