import express from "express";
import bodyParser from "body-parser";
import cors from "cors";
import dotenv from "dotenv";
import http from "http";
import { connectToDatabase } from "./database/db.js";
import { routes } from "./routes/route-manager.js";
import cron from "node-cron";
import {
  adminUserSeeder,
  commonSeederFunctions,
  roleSeeder,
} from "./seeder/seeder.js";
import { loggerMiddleware } from "./modules/logs/controllers/logs.js";
import {
  deepgramReminderMail,
  deleteDuration,
} from "./modules/delete-file-duration/controllers/duration.js";
import { Server } from "socket.io";
import { connectSocket } from "./service/socket.service.js";
import fs from "fs";
import path from "path";

export let io;

const app = express();
app.use(cors());
// app.use(express.json());
app.use(bodyParser.json({ limit: "10mb" }));
app.use(bodyParser.urlencoded({ extended: true, limit: "10mb" }));
dotenv.config();
connectToDatabase(process.env.DATABASE_URL);
app.use("/public", express.static("public"));
app.use(loggerMiddleware);

roleSeeder();
adminUserSeeder();
commonSeederFunctions();

// CREATE FOLDER TO STORE DATA
const folderPath = path.join("public", "input-file");
try {
  if (!fs.existsSync(folderPath)) {
    fs.mkdirSync(folderPath, { recursive: true });
    console.log(`Directory '${folderPath}' created successfully.`);
  } else {
    console.log(`Directory '${folderPath}' already exists.`);
  }
} catch (err) {
  console.error(`Error creating directory '${folderPath}':`, err);
}

cron.schedule("0 0 * * *", async () => {
  try {
    // Call your deleteRole function
    await deleteDuration(); // Adjust parameters if necessary
  } catch (error) {
    console.error("Error executing deleteRole function:", error);
  }
});

// ================================= DEEPGRAM REMINDER MAIL CRON JOB ================== //
cron.schedule("0 0 * * *", async () => {
  try {
    const amount = await deepgramReminderMail();
    console.log(amount);
  } catch (error) {
    console.error("Error executing deleteRole function:", error);
  }
});
app.use("/", routes);

// Create an HTTP server
const server = http.createServer(app);

// Initialize socket.io
io = new Server(server, {
  cors: {
    origin: "*",
    //origin: process.env.FRONTEND_URL || "http://localhost:3000",
    methods: ["GET", "POST"],
  },
});

// socket Connection
connectSocket(io);

const port = process.env.PORT;
const host = process.env.HOST;
server.listen(port, () => {
  console.log(`Server Started on PORT: http://${host}:${port}`);
});
