import jwt from "jsonwebtoken";
import { Role } from "../modules/role/entities/role.entity.js";
import { StatusCode, USERTYPE } from "../utils/enums.js";
import { messages } from "../utils/messages.js";
import { logger } from "../service/logger.service.js";
import { sendResponse } from "../service/common.service.js";

export const checkPermission = (resource, action) => {
  return async (req, res, next) => {
    const authHeader = req.headers["authorization"];
    if (!authHeader) {
      return res
        .status(401)
        .json({ message: "Authorization header is missing" });
    }

    const token = authHeader.split(" ")[1];
    try {
      const decoded = jwt.verify(token, process.env.JWT_SECRET);
      // const userId = decoded._id;

      const roleId = decoded.roleId;
      if (decoded.userType == USERTYPE.ADMIN) {
        const userRole = await Role.findOne({ _id: roleId });

        if (!userRole) {
          return sendResponse(
            res,
            StatusCode.NOT_FOUND,
            messages.updateUser.userNotFound
          );
        }
        const hasPermission = userRole?.permission[resource][action];
        if (!hasPermission) {
          return sendResponse(
            res,
            StatusCode.UNAUTHORIZED,
            messages.insufficient_Permissions
          );
        }
      }
      req.user = { roleId };
      next();
    } catch (error) {
      console.error("JWT verification error:", error);
      logger.error(`Getting error while check permission user : ${error}`);

      return sendResponse(
        res,
        StatusCode.UNAUTHORIZED,
        messages.user.invalidToken
      );
    }
  };
};
