import jwt from "jsonwebtoken";
import { messages } from "../utils/messages.js";
import { StatusCode, USERTYPE } from "../utils/enums.js";
import { sendResponse } from "../service/common.service.js";
import { AuthTokenSchema } from "../modules/auth/entities/authTokenSchema.js";
import mongoose from "mongoose";

// export const verifyjwt = (req, res, next) => {
//   const authHeader = req.headers["authorization"];
//   if (!authHeader)
//     return sendResponse(
//       res,
//       StatusCode.UNAUTHORIZED,
//       messages.unauthorizedUser
//     );

//   const token = authHeader.split(" ")[1];
//   try {
//     const decoded = jwt.verify(token, process.env.JWT_SECRET);

//     // Check if user status is true
//     if (decoded.userType !== USERTYPE.ADMIN && !decoded.status) {
//       return sendResponse(
//         res,
//         StatusCode.UNAUTHORIZED,
//         messages.unauthorizedUser
//       );
//     }
//     req.user = decoded;
//     next();
//   } catch (e) {
//     if (e instanceof jwt.JsonWebTokenError) {
//       return sendResponse(res, StatusCode.BADREQUEST, messages.invalidToken);
//     }
//     return sendResponse(
//       res,
//       StatusCode.INTERNAL_SERVER_ERROR,
//       messages.internalServerError
//     );
//   }
// };

export const verifyjwt = async (req, res, next) => {
  const authHeader = req.headers["authorization"];

  // Check if the authorization header is present
  if (!authHeader) {
    return sendResponse(
      res,
      StatusCode.UNAUTHORIZED,
      messages.unauthorizedUser
    );
  }

  const token = authHeader.split(" ")[1];

  try {
    const decoded = jwt.verify(token, process.env.JWT_SECRET);
    const userId = new mongoose.Types.ObjectId(decoded._id);

    const authToken = await AuthTokenSchema.findOne({ userId, token });

    if (!authToken) {
      return sendResponse(res, StatusCode.UNAUTHORIZED, messages.invalidToken);
    }
    if (decoded.userType !== USERTYPE.ADMIN && !decoded.status) {
      return sendResponse(
        res,
        StatusCode.UNAUTHORIZED,
        messages.unauthorizedUser
      );
    }

    req.user = decoded;
    next();
  } catch (e) {
    if (e instanceof jwt.JsonWebTokenError) {
      return sendResponse(res, StatusCode.BADREQUEST, messages.invalidToken);
    }
    console.error("Error verifying JWT:", e);
    return sendResponse(
      res,
      StatusCode.INTERNAL_SERVER_ERROR,
      messages.internalServerError
    );
  }
};
