import { sendResponse } from "../../../service/common.service.js";
import { logger } from "../../../service/logger.service.js";
import { StatusCode } from "../../../utils/enums.js";
import { messages } from "../../../utils/messages.js";
import { CompanySetting } from "../entities/companySettings.entities.js";
import { validateCompanySetting } from "../validator/validateCompanySetting.js";

export const getCompanySetting = async (req, res) => {
  try {
    const data = await CompanySetting.find();
    if (!data.length) {
      return sendResponse(res, StatusCode.OK, messages.noDataAvailable);
    }
    return sendResponse(res, StatusCode.OK, messages.success, {
      data,
    });
  } catch (error) {
    logger.error(`Getting error while get company setting : ${error}`);

    return sendResponse(
      res,
      StatusCode.INTERNAL_SERVER_ERROR,
      messages.internalServerError
    );
  }
};

// Update an company setting
export const updateCompanySetting = async (req, res) => {
  const { companyName, emailId, mobileNumber, url, _id, companyAddress } =
    req.body;

  const companyImage = req.file ? req.file.filename : null;

  const updatedCompanySettingData = {
    companyName,
    emailId,
    companyAddress,
    mobileNumber,
    url,
  };
  try {
    if (companyImage) {
      updatedCompanySettingData.companyImage = companyImage;
    }

    const { error } = validateCompanySetting(updatedCompanySettingData);
    if (error) {
      return sendResponse(
        res,
        StatusCode.BADREQUEST,
        error.details.map((detail) => detail.message)
      );
    } else {
      const updatedCompanySetting = await CompanySetting.findByIdAndUpdate(
        { _id: _id },
        { ...updatedCompanySettingData },
        { new: true }
      );
      if (!updatedCompanySetting) {
        return sendResponse(
          res,
          StatusCode.NOT_FOUND,
          messages.companySetting.companySettingNotFound
        );
      }

      return sendResponse(
        res,
        StatusCode.OK,
        messages.companySetting.companySettingpUpdated,
        {
          data: updatedCompanySetting,
        }
      );
    }
  } catch (error) {
    console.log("Getting error while updated company setting", error);
    logger.error(`Getting error while updated company setting : ${error}`);

    return sendResponse(
      res,
      StatusCode.INTERNAL_SERVER_ERROR,
      messages.internalServerError
    );
  }
};
