import { sendResponse } from "../../../service/common.service.js";
import { sendEmail } from "../../../service/email.service.js";
import { logger } from "../../../service/logger.service.js";
import { StatusCode } from "../../../utils/enums.js";
import { messages } from "../../../utils/messages.js";
import { inputFile } from "../../input-file/entities/inputFileSchema.js";
import { Role } from "../../role/entities/role.entity.js";
import { Duration } from "../entities/duration.entitie.js";
export const updateDuration = async (req, res) => {
  const { month } = req.body;
  const existingDuration = await Duration.find();

  try {
    const updatedDuration = await Duration.findOneAndUpdate(
      { _id: existingDuration[0]._id },
      { $set: { month: month } },
      { new: true }
    );
    return sendResponse(res, StatusCode.OK, messages.duration.durationUpdated, {
      data: { ...updatedDuration._doc },
    });
  } catch (error) {
    logger.error(`Error while updating duration: ${error}`);
    return sendResponse(
      res,
      StatusCode.INTERNAL_SERVER_ERROR,
      messages.internalServerError
    );
  }
};

export const deleteDuration = async () => {
  try {
    const existingDuration = await Duration.find();

    if (!existingDuration || existingDuration.length === 0) {
      throw new Error("No duration records found.");
    }

    const currentDate = new Date();
    const thresholdDate = new Date(currentDate);
    thresholdDate.setMonth(
      thresholdDate.getMonth() - existingDuration[0].month
    );

    const rolesToDelete = await Role.find({
      createdAt: { $lt: thresholdDate },
    });

    for (let role of rolesToDelete) {
      await Role.findByIdAndDelete(role._id);
    }

    return { message: "Roles deleted successfully." };
  } catch (error) {
    if (error.message === "No duration records found.") {
      return { message: "No duration records found. No roles deleted." };
    } else {
      logger.error(`Error while deleting duration: ${error}`);
      throw new Error("Failed to delete roles.");
    }
  }
};

export const getDuration = async (req, res) => {
  const existingDuration = await Duration.find();

  if (!existingDuration || existingDuration.length === 0) {
    return sendResponse(res, StatusCode.OK, messages.noDataAvailable);
  }
  try {
    const duration = await Duration.findOne({ _id: existingDuration[0]?._id });
    if (!duration) {
      return sendResponse(
        res,
        StatusCode.NOT_FOUND,
        messages.duration.durationNotFound
      );
    }
    return sendResponse(res, StatusCode.OK, messages.success, {
      data: duration,
    });
  } catch (error) {
    logger.error(`Getting error while  get duration by id : ${error}`);

    console.error("Error fetching duration:", error);
    return sendResponse(
      res,
      StatusCode.INTERNAL_SERVER_ERROR,
      messages.internalServerError
    );
  }
};

export const deepgramReminderMail = async () => {
  try {
    const totalAmountArray = await inputFile.find({}, { amount: 1, _id: 0 });
    const totalAmount = totalAmountArray.reduce(
      (acc, item) => acc + item.amount,
      0
    );

    const finalAmount = Number(totalAmount.toFixed(3));

    if (totalAmount > 180) {
      let emailHTML = `<div class="coupon" style="
                          border: 0px;
                          width: 95%;
                          border-radius: 0px;
                          margin: 0 auto;
                          max-width: 600px;
                          font-family: Arial;
                        ">
                        <div style="
                            padding: 23px 16px;
                            background-color: #c4b4fc;
                            text-align: center;
                            border-radius: 0 0;
                          ">
                          <a href="#">
                            <img src="http://148.72.246.221:81/summary-ai/app/_next/static/media/logo.db9ce2e5.png" alt="logo"
                              style="padding: 10px 0px;max-width: 200px; height: auto;" />
                          </a>
                        </div>
                        <div style="background-color: white; padding: 0 16px">
                          <p style="
                              font-size: 14px;
                              font-family: Arial, sans-serif;
                              color: #2b303a;
                              margin: 25px 0 0;
                              text-transform: capitalize;
                            ">
                            Dear <b>Admin,</b>
                          </p>
                        </div>
                        <div style="font-family: sans-serif; padding: 10px 16px 50px">
                          <div class="" style="
                              font-size: 12px;
                              font-family: Arial, sans-serif;
                              mso-line-height-alt: 18px;
                              color: #555555;
                              line-height: 1.5;
                            ">
                            <p style="
                                margin: 0;
                                font-size: 14px;
                                text-align: left;
                                mso-line-height-alt: 22.5px;
                              "></p>                              
                            <p>We would like to inform you that the Deepgram account has reached a usage threshold ${finalAmount} for the current
                              billing period.</p>
                            <p>
                              Please review the account activity to ensure smooth continuity of service and consider taking appropriate
                              actions if
                              necessary to prevent any disruptions.
                            </p>
                            <p>
                              <span>Best Regards,</span><br /><span><b>Summary AI Team</b></span>
                            </p>
                          </div>
                        </div>

                        <div style="background-color: #c4b4fc">
                          <div style="
                              padding: 2px 16px;
                              text-align: center;
                              border-radius: 0 0;
                              border: 0;
                            ">
                            <a href="#" style="border: 0">
                              <img src="http://148.72.246.221:81/summary-ai/app/_next/static/media/logo.db9ce2e5.png" alt="logo"
                                style="padding: 10px 0px;max-width: 200px; height: auto;" />
                            </a>
                          </div>
                          <div align="center" class="alignment" style="padding: 2px 16px; text-align: center; border-radius: 0 0">
                            <div style="padding: 2px 16px; text-align: center; border-radius: 0 0">
                              <div class="" style="
                                  font-size: 14px;
                                  font-family: Arial, sans-serif;
                                  mso-line-height-alt: 14.399999999999999px;
                                  color: #555555;
                                  line-height: 1.2;
                                ">
                                <p style="
                                    margin: 0;
                                    font-size: 14px;
                                    text-align: center;
                                    mso-line-height-alt: 16.8px;
                                    padding: 0 0 18px 0;
                                  ">
                                  <span style="color: #000; font-size: 14px">Copyright © 2024 Summary AI Services - All rights
                                    reserved.</span>
                                </p>
                              </div>
                            </div>
                          </div>
                        </div>
                      </div>`;

      await sendEmail({
        from: process.env.SENDER_EMAIL,
        to: process.env.SENDER_EMAIL,
        subject: `Your Deepgram account cross ${finalAmount} dollar`,
        html: emailHTML,
      });
    }
    return "Deepgram reminder mail send successfully to admin";
  } catch (error) {
    console.log(`Deepgram Reminder Mail: ${error}`);
    logger.error(`Deepgram Reminder Mail: ${error}`);
    throw new Error("Failed to delete roles.");
  }
};
