import Joi from "joi";
import { validationMessages } from "../../../utils/validationMessages.js";

export function validateGroup(data) {
  const schema = Joi.object({
    groupName: Joi.string()
      .min(2)
      .max(100)
      .required()
      .messages(validationMessages.groupName),

    ageGroup: Joi.object({
      minAge: Joi.number()
        .integer()
        .min(0)
        .required()
        .messages(validationMessages.minAge),
      maxAge: Joi.number()
        .integer()
        .min(Joi.ref("minAge"))
        .required()
        .messages(validationMessages.maxAge),
    })
      .required()
      .messages(validationMessages.ageGroup),

    subscriptionPlan: Joi.array()
      .items(Joi.string().hex().length(24))

      .messages(validationMessages.subscriptionPlan),

    transcribeUsageRange: Joi.object({
      minUsage: Joi.number().required().messages(validationMessages.minUsage),
      maxUsage: Joi.number().required().messages(validationMessages.maxUsage),
    })
      .required()
      .messages(validationMessages.transcribeUsageRange),

    users: Joi.array()
      .items(Joi.string().hex().length(24))
      .messages(validationMessages.users),

    status: Joi.boolean().required().messages(validationMessages.status),
  });

  return schema.validate(data, { abortEarly: false }); // abortEarly: false to collect all errors
}
