import {
  getTokenUserInfo,
  sendResponse,
} from "../../../service/common.service.js";
import { StatusCode } from "../../../utils/enums.js";
import { messages } from "../../../utils/messages.js";
import {
  convertUrlToTitle,
  fetchUsersWithFilterAndPagination,
} from "../../../utils/utils.js";
import { Logs } from "../entities/logs.entities.js";

export const getApiLogs = async (req, res) => {
  try {
    const { search, page, take, role } = req.query;
    let userInfo = getTokenUserInfo(req);

    let searchQuery = { _id: { $ne: userInfo._id } };
    if (search) {
      searchQuery = {
        $or: [
          { username: new RegExp(search, "i") },
          { email: new RegExp(search, "i") },
        ],
      };
    }

    let filters = {};
    if (role) filters.role = role;

    const options = {
      searchQuery,
      filter: filters,
      page: parseInt(page) || 1,
      take: parseInt(take) || 10,
    };
    const {
      data: data,
      totalData,
      page: currentPage,
      take: perPage,
      totalPages,
      prevPage,
      nextPage,
    } = await fetchUsersWithFilterAndPagination(Logs, options);

    if (!data.length) {
      return sendResponse(res, StatusCode.OK, messages.noDataAvailable);
    }

    return sendResponse(res, StatusCode.OK, messages.success, {
      data: data,
      pagination: {
        nextPage,
        page: currentPage,
        prevPage,
        take: perPage,
        totalData,
        totalPages,
      },
    });
  } catch (error) {
    console.log("Getting error while add user & signUp", error);

    return sendResponse(
      res,
      StatusCode.INTERNAL_SERVER_ERROR,
      messages.internalServerError
    );
  }
};

export const logRequest = async (req, res, status, responseTime) => {
  const log = new Logs({
    method: req.method,
    url: req.originalUrl,
    status: status,
    responseTime: responseTime,
  });

  try {
    await log.save();
  } catch (err) {
    console.error("Error saving log:", err);
  }
};

export const loggerMiddleware = async (req, res, next) => {
  const start = Date.now();

  res.on("finish", async () => {
    const log = new Logs({
      method: req.method,
      url: req.originalUrl,
      status: res.statusCode,
      responseTime: Date.now() - start,
      title: convertUrlToTitle(req.originalUrl),
    });

    try {
      await log.save();
    } catch (err) {
      console.error("Error saving log:", err);
    }
  });

  next();
};
