import mongoose from "mongoose";
import { NOTIFICATION } from "../../../utils/enums.js";

const notificationSchema = new mongoose.Schema(
  {
    title: {
      type: String,
      required: true,
    },
    groupId: {
      type: mongoose.Types.ObjectId,
      ref: "group",
      required: function () {
        return this.notificationType === NOTIFICATION.GROUP_NOTIFICATION;
      },
    },
    userId: {
      type: mongoose.Types.ObjectId,
      ref: "users",
      required: function () {
        return this.notificationType === NOTIFICATION.INDIVIDUAL_NOTIFICATION;
      },
    },
    message: {
      type: String,
      required: true,
    },
    notificationType: {
      type: String,
      enum: [
        NOTIFICATION.GROUP_NOTIFICATION,
        NOTIFICATION.INDIVIDUAL_NOTIFICATION,
        NOTIFICATION.ALL_USERS,
      ],
      required: true,
    },
    createdAt: {
      type: Date,
      default: Date.now,
    },
    updatedAt: {
      type: Date,
      default: Date.now,
    },
  },
  {
    timestamps: true,
  }
);

export const Notification = mongoose.model("notification", notificationSchema);

const allUsersnotificationSchema = new mongoose.Schema({
  notificationId: {
    type: mongoose.Types.ObjectId,
    ref: "notification",
    required: true,
  },

  userId: {
    type: mongoose.Types.ObjectId,
    ref: "users",
    required: true,
  },

  isSeen: {
    type: Boolean,
    required: true,
    default: false,
  },
});

export const AllUsersNotificationSchema = mongoose.model(
  "allUsersNotification",
  allUsersnotificationSchema
);
