import Joi from "joi";
import { validationMessages } from "../../../utils/validationMessages.js";
import { NOTIFICATION } from "../../../utils/enums.js";

export function validateNotification(data) {
  const schema = Joi.object({
    title: Joi.string()
      .min(3)
      .max(100)
      .required()
      .messages(validationMessages.title),
    groupId: Joi.string()
      .regex(/^[0-9a-fA-F]{24}$/)
      .when("notificationType", {
        is: NOTIFICATION.GROUP_NOTIFICATION,
        then: Joi.required(),
      })
      .messages(validationMessages.groupId),
    userId: Joi.string()
      .regex(/^[0-9a-fA-F]{24}$/)
      .when("notificationType", {
        is: NOTIFICATION.INDIVIDUAL_NOTIFICATION,
        then: Joi.required(),
      })
      .messages(validationMessages.userId),
    message: Joi.string()
      .min(3)
      .max(500)
      .required()
      .messages(validationMessages.message),
    notificationType: Joi.string()
      .valid(
        NOTIFICATION.GROUP_NOTIFICATION,
        NOTIFICATION.INDIVIDUAL_NOTIFICATION,
        NOTIFICATION.ALL_USERS
      )
      .required()
      .messages(validationMessages.notificationType),
  });

  return schema.validate(data, { abortEarly: false }); // abortEarly: false to collect all errors
}
