import { sendResponse } from "../../../service/common.service.js";
import { logger } from "../../../service/logger.service.js";
import { StatusCode } from "../../../utils/enums.js";
import { messages } from "../../../utils/messages.js";
import { PrivacyPolicy } from "../entities/privacyPolicy.entitie.js";
import { validatePrivacyPolicy } from "../validator/validatePrivacyPolicy.js";

export const getPrivacyPolicy = async (req, res) => {
  try {
    const data = await PrivacyPolicy.find();
    if (!data.length) {
      return sendResponse(res, StatusCode.OK, messages.noDataAvailable);
    }
    return sendResponse(res, StatusCode.OK, messages.success, {
      data,
    });
  } catch (error) {
    logger.error(`Getting error while get privacy policy: ${error}`);

    return sendResponse(
      res,
      StatusCode.INTERNAL_SERVER_ERROR,
      messages.internalServerError
    );
  }
};

export const updatePrivacyPolicy = async (req, res) => {
  const { privacyPolicy, _id } = req.body;
  const updatedPrivacyPolicyData = { privacyPolicy };
  try {
    const { error } = validatePrivacyPolicy(updatedPrivacyPolicyData);
    if (error) {
      return sendResponse(
        res,
        StatusCode.BADREQUEST,
        error.details.map((detail) => detail.message)
      );
    } else {
      const updatedPrivacyPolicy = await PrivacyPolicy.findByIdAndUpdate(
        { _id: _id },
        { $set: updatedPrivacyPolicyData },
        { new: true }
      );
      if (!updatedPrivacyPolicy) {
        return sendResponse(
          res,
          StatusCode.NOT_FOUND,
          messages.privacyPolicy.privacyPolicyNotFound
        );
      }

      return sendResponse(
        res,
        StatusCode.OK,
        messages.privacyPolicy.privacyPolicyUpdated,
        {
          data: updatedPrivacyPolicy,
        }
      );
    }
  } catch (error) {
    logger.error(`Getting error while updated privacy policy: ${error}`);

    return sendResponse(
      res,
      StatusCode.INTERNAL_SERVER_ERROR,
      messages.internalServerError
    );
  }
};
