import Joi from "joi";
import { validationMessages } from "../../../utils/validationMessages.js";

export function validateSubscription(data) {
  const schema = Joi.object({
    subscriptionTitle: Joi.string()
      .min(3)
      .max(100)
      .required()
      .messages(validationMessages.subscriptionTitle),
    planDuration: Joi.string()
      .required()
      .messages(validationMessages.planDuration),
    subscriptionContent: Joi.string()
      .required()
      .messages(validationMessages.subscriptionContent),
    subscriptionAmount: Joi.number()

      .required()
      .messages(validationMessages.subscriptionAmount),
    startDate: Joi.date()
      .iso()
      .required()
      .messages(validationMessages.startDate),
    endDate: Joi.date()
      .iso()
      .greater(Joi.ref("startDate"))
      .required()
      .messages(validationMessages.endDate),
    status: Joi.boolean().required().messages(validationMessages.status),
  });
  return schema.validate(data, { abortEarly: false }); // abortEarly: false to collect all errors
}
