import {
  getTokenUserInfo,
  sendResponse,
} from "../../../service/common.service.js";
import { sendEmail } from "../../../service/email.service.js";
import { StatusCode } from "../../../utils/enums.js";
import { messages } from "../../../utils/messages.js";
import { SupportRequestSchema } from "../entities/supportRequestSchema.js";
import { validateSupportRequest } from "../validator/validateSupportRequest.js";

export const AddSupportRequest = async (req, res) => {
  const { title, description } = req.body;
  const userInfo = getTokenUserInfo(req);

  if (!title || !description) {
    return sendResponse(res, StatusCode.BADREQUEST, messages.allFieldsRequired);
  }

  const { error } = validateSupportRequest(req.body);
  if (error) {
    return sendResponse(
      res,
      StatusCode.BADREQUEST,
      error.details.map((detail) => detail.message)
    );
  } else {
    const newSupportRequestData = new SupportRequestSchema({
      title,
      description,
    });
    const savedSupportRequest = await newSupportRequestData.save();

    let emailHTML = `
              <div class="coupon" style="
                border: 0px;
                width: 95%;
                border-radius: 0px;
                margin: 0 auto;
                max-width: 600px;
                font-family: Arial;
              ">
              <div style="
                  padding: 23px 16px;
                  background-color: #c4b4fc ;
                  text-align: center;
                  border-radius: 0 0;
                ">
                <a href="#">
                  <img src="http://148.72.246.221:81/summary-ai/app/_next/static/media/logo.db9ce2e5.png" alt="logo"
                    style="padding: 10px 0px;max-width: 200px; height: auto;" />
                </a>
              </div>
              <div style="background-color: white; padding: 0 16px">
                <p style="
                    font-size: 14px;
                    font-family: Arial, sans-serif;
                    color: #2b303a;
                    margin: 25px 0 0;
                    text-transform: capitalize;
                  ">
                  Dear <b>Team</b>
                </p>
              </div>
              <div style="font-family: sans-serif; padding: 20px 16px 50px">
                <div class="" style="
                    font-size: 12px;
                    font-family: Arial, sans-serif;
                    mso-line-height-alt: 18px;
                    color: #555555;
                    line-height: 1.5;
                  ">
                  <p style="
                      margin: 0;
                      font-size: 14px;
                      text-align: left;
                      mso-line-height-alt: 22.5px;
                    "></p>

                  <p><b>Email</b> : ${userInfo.email}</p>
                  <p>${savedSupportRequest.description}</p>
                  <p>
                    <span>Best Regards,</span><br /><span><b>Summary AI Team</b></span>
                  </p>

                </div>
              </div>

              <div style="background-color: #c4b4fc ">
                <div style="
                    padding: 2px 16px;
                    text-align: center;
                    border-radius: 0 0;
                    border: 0;
                  ">
                  <a href="#" style="border: 0">
                    <img src="http://148.72.246.221:81/summary-ai/app/_next/static/media/logo.db9ce2e5.png" alt="logo"
                      style="padding: 10px 0px;max-width: 200px; height: auto;" />
                  </a>
                </div>
                <div align="center" class="alignment" style="padding: 2px 16px; text-align: center; border-radius: 0 0">
                  <div style="padding: 2px 16px; text-align: center; border-radius: 0 0">
                    <div class="" style="
                        font-size: 14px;
                        font-family: Arial, sans-serif;
                        mso-line-height-alt: 14.399999999999999px;
                        color: #555555;
                        line-height: 1.2;
                      ">
                      <p style="
                          margin: 0;
                          font-size: 14px;
                          text-align: center;
                          mso-line-height-alt: 16.8px;
                          padding: 0 0 18px 0;
                        ">
                        <span style="color: #000; font-size: 14px">Copyright © 2024 Summary AI Services - All rights
                          reserved.</span>
                      </p>
                    </div>
                  </div>
                </div>
              </div>
            </div>`;

    const emailSent = await sendEmail({
      from: userInfo.email,
      to: process.env.SENDER_EMAIL,
      subject: savedSupportRequest.title,
      html: emailHTML,
    });

    if (!emailSent) {
      return sendResponse(
        res,
        StatusCode.INTERNAL_SERVER_ERROR,
        "Error sending verification email"
      );
    }

    return sendResponse(
      res,
      StatusCode.CREATE,
      messages.supportRequest.success,
      savedSupportRequest
    );
  }
};
