import { sendResponse } from "../../../service/common.service.js";
import { logger } from "../../../service/logger.service.js";
import { StatusCode } from "../../../utils/enums.js";
import { messages } from "../../../utils/messages.js";
import { TermsCondition } from "../entities/termsConditions-entitie.js";
import { validateTermsConditions } from "../validator/validateTermsConditions.js";

export const getTermsCondition = async (req, res) => {
  try {
    const data = await TermsCondition.find();
    if (!data.length) {
      return sendResponse(res, StatusCode.OK, messages.noDataAvailable);
    }
    return sendResponse(res, StatusCode.OK, messages.success, {
      data,
    });
  } catch (error) {
    logger.error(`Getting error while get terms and condition: ${error}`);

    return sendResponse(
      res,
      StatusCode.INTERNAL_SERVER_ERROR,
      messages.internalServerError
    );
  }
};

export const updateTermsCondition = async (req, res) => {
  const { termsCondition, _id } = req.body;
  const updatedTermsConditionData = { termsCondition };

  try {
    const { error } = validateTermsConditions(updatedTermsConditionData);
    if (error) {
      return sendResponse(
        res,
        StatusCode.BADREQUEST,
        error.details.map((detail) => detail.message)
      );
    } else {
      const updatedTermsCondition = await TermsCondition.findByIdAndUpdate(
        { _id: _id },
        { $set: updatedTermsConditionData },
        { new: true }
      );
      if (!updatedTermsCondition) {
        return sendResponse(
          res,
          StatusCode.NOT_FOUND,
          messages.termsCondition.termsConditionNotFound
        );
      }

      return sendResponse(
        res,
        StatusCode.OK,
        messages.termsCondition.termsConditionUpdated,
        {
          data: updatedTermsCondition,
        }
      );
    }
  } catch (error) {
    logger.error(`Getting error while update terms and condition: ${error}`);

    return sendResponse(
      res,
      StatusCode.INTERNAL_SERVER_ERROR,
      messages.internalServerError
    );
  }
};
