import mongoose from "mongoose";
import { USERTYPE } from "../../../utils/enums.js";

const userSchema = new mongoose.Schema({
  username: {
    type: String,
    required: true,
    min: 3,
    max: 100,
  },
  email: {
    type: String,
    required: true,

    min: 5,
    max: 255,
  },
  password: {
    type: String,
    required: function () {
      this.userType !== USERTYPE.ADMIN;
    },
    min: 3,
    max: 100,
  },

  role: {
    type: mongoose.Types.ObjectId,
    null: false,
    ref: "role",
  },

  userType: {
    type: String,
    enum: [USERTYPE.ADMIN, USERTYPE.USER],
    required: true,
    default: USERTYPE.USER,
  },
  otp: {
    type: String,
  },
  otpSentTime: {
    type: Date,
  },
  status: {
    type: Boolean,
    default: true,
  },
});

export const User = mongoose.model("users", userSchema);

const appUserSchema = new mongoose.Schema({
  username: {
    type: String,
    required: true,
    min: 3,
    max: 100,
  },
  email: {
    type: String,
    required: true,

    min: 5,
    max: 255,
  },
  userId: {
    type: mongoose.Types.ObjectId,
    null: false,
    ref: "Users",
  },
  profileImage: {
    type: String, // Assuming you'll store the path or URL of the image
  },
  status: {
    type: Boolean,
    default: true,
  },
  userType: {
    type: String,
    enum: [USERTYPE.ADMIN, USERTYPE.USER],
    required: true,
  },
  phone: {
    type: Number,
  },
  otp: {
    type: String,
  },

  isVerify: {
    type: Boolean,
    default: false,
  },
  loginCount: { type: Number, default: 0 },
});

export const AppUser = mongoose.model("appUsers", appUserSchema);

const adminSchema = new mongoose.Schema({
  profileImage: {
    type: String, // Assuming you'll store the path or URL of the image
  },
  userId: {
    type: mongoose.Types.ObjectId,
    null: false,
    ref: "Users",
  },
  username: {
    type: String,
    required: true,
    min: 3,
    max: 100,
  },

  email: {
    type: String,
    required: true,

    min: 5,
    max: 255,
  },
  phone: {
    type: String,
    required: true,
    //
  },
  status: {
    type: Boolean,
    required: true,
  },
  role: {
    type: mongoose.Types.ObjectId,
    null: false,
    ref: "role",
  },

  userType: {
    type: String,
    enum: [USERTYPE.ADMIN, USERTYPE.USER],
    required: true,
  },
});

export const AdminUser = mongoose.model("adminUser", adminSchema);
