import Joi from "joi";
import { validationMessages } from "../../utils/validationMessages.js";
import { USERTYPE } from "../../utils/enums.js";

export function validateUser(user) {
  const schema = Joi.object({
    username: Joi.string()
      .min(3)
      .max(100)
      .required()
      .messages(validationMessages.username),
    email: Joi.string()
      .min(5)
      .max(255)
      .required()
      .email()
      .messages(validationMessages.email),
    phone: Joi.number().required().messages(validationMessages.phone),

    // phone: Joi.when("userType", {
    //   is: USERTYPE.ADMIN,
    //   then: Joi.number().required().messages(validationMessages.phone),
    //   otherwise: Joi.forbidden(), // Prevent role field for NormalUser
    // }),
    password: Joi.when("userType", {
      is: USERTYPE.ADMIN,
      then: Joi.forbidden(), // Prevent password field for Admin
      otherwise: Joi.string()
        .min(6)
        .required()
        .messages(validationMessages.password), // Require password for NormalUser
    }),

    userType: Joi.string()
      .min(3)
      .max(100)
      .required()
      .messages(validationMessages.userType),
    role: Joi.when("userType", {
      is: USERTYPE.ADMIN,
      then: Joi.string().required().messages(validationMessages.role),
      otherwise: Joi.forbidden(), // Prevent role field for NormalUser
    }),
    profileImage: Joi.when("userType", {
      is: USERTYPE.ADMIN,
      then: Joi.string().messages(validationMessages.profileImage),
      otherwise: Joi.forbidden(), // Prevent role field for NormalUser
    }),

    status: Joi.when("userType", {
      is: USERTYPE.ADMIN,
      then: Joi.boolean().required().messages(validationMessages.status),
      otherwise: Joi.forbidden(), // Prevent role field for NormalUser
    }),
  });
  return schema.validate(user, { abortEarly: false }); // abortEarly: false to collect all errors
}
