import express from "express";
import {
  changePassword,
  googleAuth,
  logOutDevice,
  resendOTP,
  resetPassword,
  signIn,
  verifyOTP,
} from "../modules/auth/controllers/auth.js";
import { addUser } from "../modules/user/controllers/user.js";
import { uploadSingle } from "../helpers/multer.js";
import { verifyjwt } from "../middleware/verifyjwt.js";

const authRoute = express.Router();
authRoute.post("/auth/sign-in", signIn);
authRoute.post(
  "/auth/sign-up",
  uploadSingle("public/", "profileImage"),
  addUser
);
authRoute.post("/auth/verifyOTP", verifyOTP);
authRoute.post("/auth/googleAuth", googleAuth);

authRoute.post("/auth/resend-otp", resendOTP);
authRoute.post("/auth/forgot-password", resendOTP);
authRoute.post("/auth/reset-password", resetPassword);
authRoute.post("/auth/change-password", verifyjwt, changePassword);
authRoute.post("/auth/logout", verifyjwt, logOutDevice);

export default authRoute;
