import express from "express";
import { verifyjwt } from "../middleware/verifyjwt.js";
import {
  addFaqs,
  deleteFaqs,
  getFaqs,
  getFaqsById,
  updateFaqs,
} from "../modules/faqs/controllers/faqs.js";
import { checkPermission } from "../middleware/checkPermission.js";

const faqsRoute = express.Router();

faqsRoute.post(
  "/add-faq",
  verifyjwt,
  checkPermission("FAQs", "isAdd"),
  addFaqs
);
faqsRoute.patch(
  "/faq",
  checkPermission("FAQs", "isEdit"),
  verifyjwt,
  updateFaqs
);
faqsRoute.get("/faqs", checkPermission("FAQs", "isView"), verifyjwt, getFaqs);
faqsRoute.delete(
  "/faq/:id",
  checkPermission("FAQs", "isDelete"),
  verifyjwt,
  deleteFaqs
);
faqsRoute.get(
  "/faq/:id",
  checkPermission("FAQs", "isView"),
  verifyjwt,
  getFaqsById
);

export default faqsRoute;
