import express from "express";

import { verifyjwt } from "../middleware/verifyjwt.js";
import {
  createGroup,
  deleteGroup,
  getGroupById,
  getGroups,
  getGroupsWithOutPagination,
  updateGroup,
} from "../modules/group/controllers/group.js";
import { checkPermission } from "../middleware/checkPermission.js";

const groupRoute = express.Router();

groupRoute.post(
  "/create-group",
  verifyjwt,
  checkPermission("groupManagement", "isAdd"),
  createGroup
);
groupRoute.get(
  "/groups",
  verifyjwt,
  checkPermission("groupManagement", "isView"),
  getGroups
);
groupRoute.get(
  "/all-groups",
  verifyjwt,
  checkPermission("groupManagement", "isView"),
  getGroupsWithOutPagination
);
groupRoute.patch(
  "/group",
  verifyjwt,
  checkPermission("groupManagement", "isEdit"),
  updateGroup
);
groupRoute.get(
  "/group/:id",
  verifyjwt,
  checkPermission("groupManagement", "isView"),
  getGroupById
);
groupRoute.delete(
  "/group/:id",
  verifyjwt,
  checkPermission("groupManagement", "isDelete"),
  deleteGroup
);

export default groupRoute;
