import express from "express";
import { verifyjwt } from "../middleware/verifyjwt.js";
import {
  addLanguage,
  deletelanguage,
  getLanguageById,
  getLanguages,
  updateLanguage,
} from "../modules/language-setup/controllers/language-setup.js";
import { checkPermission } from "../middleware/checkPermission.js";

const languageRoute = express.Router();

languageRoute.post(
  "/add-language",
  verifyjwt,
  checkPermission("languageSetup", "isAdd"),
  addLanguage
);
languageRoute.patch(
  "/language",
  verifyjwt,
  checkPermission("languageSetup", "isEdit"),
  updateLanguage
);
languageRoute.get(
  "/languages",
  verifyjwt,
  checkPermission("languageSetup", "isView"),
  getLanguages
);
languageRoute.delete(
  "/language/:id",
  verifyjwt,
  checkPermission("languageSetup", "isDelete"),
  deletelanguage
);
languageRoute.get(
  "/language/:id",
  verifyjwt,
  checkPermission("languageSetup", "isView"),
  getLanguageById
);

export default languageRoute;
