import express from "express";
import { verifyjwt } from "../middleware/verifyjwt.js";
import {
  addOutputFormat,
  deleteOutputFormat,
  getOutputFormatById,
  getOutputFormats,
  updateOutputFormat,
} from "../modules/output-format/controllers/output-format.js";
import { checkPermission } from "../middleware/checkPermission.js";

const outputFormatRoute = express.Router();

outputFormatRoute.post(
  "/add-output-format",
  verifyjwt,
  checkPermission("outputFormat", "isAdd"),
  addOutputFormat
);
outputFormatRoute.patch(
  "/output-format",
  verifyjwt,
  checkPermission("outputFormat", "isEdit"),
  updateOutputFormat
);
outputFormatRoute.get(
  "/output-formats",
  verifyjwt,
  checkPermission("outputFormat", "isView"),
  getOutputFormats
);
outputFormatRoute.delete(
  "/output-format/:id",
  verifyjwt,
  checkPermission("outputFormat", "isDelete"),
  deleteOutputFormat
);
outputFormatRoute.get(
  "/output-format/:id",
  verifyjwt,
  checkPermission("outputFormat", "isView"),
  getOutputFormatById
);

export default outputFormatRoute;
