import express from "express";
import {
  addRole,
  deleteRole,
  getAdminRoles,
  getRoleById,
  getRoles,
  updateRole,
} from "../modules/role/controllers/role.js";
import { verifyjwt } from "../middleware/verifyjwt.js";
import { checkPermission } from "../middleware/checkPermission.js";

const roleRoute = express.Router();

roleRoute.post(
  "/add-role",
  verifyjwt,
  checkPermission("roles", "isAdd"),
  addRole
);
roleRoute.patch(
  "/role",
  checkPermission("roles", "isEdit"),
  verifyjwt,
  updateRole
);
roleRoute.get(
  "/roles",
  checkPermission("roles", "isView"),
  verifyjwt,
  getRoles
);
roleRoute.get(
  "/admin-roles",
  checkPermission("roles", "isView"),
  getAdminRoles
);
roleRoute.delete(
  "/role/:id",
  checkPermission("roles", "isDelete"),
  verifyjwt,
  deleteRole
);
roleRoute.get(
  "/role/:id",
  checkPermission("roles", "isView"),
  verifyjwt,
  getRoleById
);

export default roleRoute;
