import express from "express";
import { verifyjwt } from "../middleware/verifyjwt.js";
import {
  addSubscription,
  deleteSubscription,
  getSubscriptionById,
  getSubscriptions,
  updateSubscription,
} from "../modules/subscription/controllers/subscription.js";
import { checkPermission } from "../middleware/checkPermission.js";

const subscriptionRoue = express.Router();

subscriptionRoue.post(
  "/add-subscription",
  verifyjwt,
  checkPermission("subscriptions", "isAdd"),
  addSubscription
);
subscriptionRoue.patch(
  "/subscription",
  verifyjwt,
  checkPermission("subscriptions", "isEdit"),
  updateSubscription
);
subscriptionRoue.get(
  "/subscriptions",
  verifyjwt,
  checkPermission("subscriptions", "isView"),
  getSubscriptions
);
subscriptionRoue.delete(
  "/subscription/:id",
  verifyjwt,
  checkPermission("subscriptions", "isDelete"),
  deleteSubscription
);
subscriptionRoue.get(
  "/subscription/:id",
  verifyjwt,
  checkPermission("subscriptions", "isView"),
  getSubscriptionById
);

export default subscriptionRoue;
