import express from "express";
import { verifyjwt } from "../middleware/verifyjwt.js";
import {
  addTranscriptionQuality,
  deleteTranscriptionQuality,
  getTranscriptionQuality,
  getTranscriptionQualityById,
  updateTranscriptionQuality,
} from "../modules/transcription-quality/controllers/transcription-quality.js";
import { checkPermission } from "../middleware/checkPermission.js";

const transcriptionQualityRoute = express.Router();

transcriptionQualityRoute.post(
  "/add-transcription-quality",
  verifyjwt,
  checkPermission("transcriptionQuality", "isAdd"),
  addTranscriptionQuality
);
transcriptionQualityRoute.patch(
  "/transcription-quality",
  verifyjwt,
  checkPermission("transcriptionQuality", "isEdit"),
  updateTranscriptionQuality
);
transcriptionQualityRoute.get(
  "/transcription-qualityes",
  verifyjwt,
  checkPermission("transcriptionQuality", "isView"),
  getTranscriptionQuality
);
transcriptionQualityRoute.delete(
  "/transcription-quality/:id",
  verifyjwt,
  checkPermission("transcriptionQuality", "isDelete"),
  deleteTranscriptionQuality
);
transcriptionQualityRoute.get(
  "/transcription-quality/:id",
  verifyjwt,
  checkPermission("transcriptionQuality", "isView"),
  getTranscriptionQualityById
);

export default transcriptionQualityRoute;
