import express from "express";
import {
  addUser,
  deleteUser,
  getAppUsers,
  getUser,
  getUsers,
  updateUser,
} from "../modules/user/controllers/user.js";
import { verifyjwt } from "../middleware/verifyjwt.js";
import { uploadSingle } from "../helpers/multer.js";
import { checkPermission } from "../middleware/checkPermission.js";

const userRoute = express.Router();
userRoute.post(
  "/add-user",
  verifyjwt,
  checkPermission("users", "isAdd"),

  uploadSingle("public/", "profileImage"),
  addUser
);

userRoute.get(
  "/users",
  verifyjwt,
  checkPermission("users", "isView"),
  getUsers
);
userRoute.get(
  "/user/:id",
  verifyjwt,
  checkPermission("users", "isView"),
  getUser
);
userRoute.patch(
  "/user",
  verifyjwt,
  checkPermission("users", "isEdit"),
  uploadSingle("public/", "profileImage"),
  updateUser
);
userRoute.delete(
  "/user/:id",
  verifyjwt,
  checkPermission("users", "isDelete"),
  deleteUser
);
userRoute.get("/app-users", verifyjwt, getAppUsers);

export default userRoute;
