import jwt from "jsonwebtoken";
import fs from "fs";

export const sendResponse = (res, statusCode, message, data, token) => {
  let response = {
    statusCode: statusCode,
    message,
    data,
    token,
  };

  if ([null, undefined].includes(response.data)) delete response.data;
  if ([null, undefined].includes(response.token)) delete response.token;

  return res.status(statusCode).json(response);
};

export const getTokenUserInfo = (req) => {
  try {
    const authHeader = req.headers["authorization"];

    if (!authHeader) {
      throw new Error("Authorization header is missing");
    }

    const token = authHeader.split(" ")[1]; // Assuming JWT format "Bearer token"
    if (!token) {
      throw new Error("Authorization token is missing");
    }

    const decoded = jwt.verify(token, process.env.JWT_SECRET);
    return decoded;
  } catch (error) {
    throw error; // Re-throw the error for proper handling
  }
};

//====================================== IMAGE VALIDATOR ===========================================//
export const validFileType = (req, res, next) => {
  try {
    const mime = [
      "video/mp4",
      "video/mov",
      "video/quicktime",
      "audio/mpeg",
      "audio/mp3",
    ];
    const mimeTypes = [];

    // check for the mimetypes of files

    for (const key in req.files) {
      if (req.files[key]) {
        let filesArray = req.files[key];

        // If it's not an array, convert it into an array
        if (!Array.isArray(filesArray)) {
          filesArray = [filesArray];
        }

        filesArray.forEach((file) => {
          const mimeType = file.mimetype;
          mimeTypes.push(mimeType);
        });
      }
    }

    let allMatched = mimeTypes.every((mimetype) => mime.includes(mimetype));

    // if the mimetype does not match the allowed mimetypes, then delete the files
    if (!allMatched) {
      for (const key in req.files) {
        if (req.files[key]) {
          let filesArray = req.files[key];

          // Convert to array if it's not
          if (!Array.isArray(filesArray)) {
            filesArray = [filesArray];
          }

          filesArray.forEach((file) => {
            fs.unlink(file.path, (err) => {
              if (err) {
                console.error("Error deleting file:", err);
              }
            });
          });
        }
      }
      return res.status(400).send({
        statuscode: 400,
        message: "Invalid file type",
      });
    }
    next();
  } catch (error) {
    // handle the server errors if any
    console.log("error while validating file", error);
    return res.status(400).send({
      statuscode: 400,
      message: "Invalid file type",
    });
  }
};
