import nodemailer from "nodemailer";
import jwt from "jsonwebtoken";
import { logger } from "./logger.service.js";

export async function sendEmail({ from, to, subject, text, html }) {
  try {
    let transporter = nodemailer.createTransport({
      host: process.env.SENDGRID_HOST,
      port: process.env.SENDGRID_PORT,
      auth: {
        user: process.env.SENDER_EMAIL,
        pass: process.env.SENDGRID_SECRET_KEY,
      },
    });

    let payload = {
      from: from,
      to: to,
      subject: subject,
      text: text,
      html: html,
    };

    // if (rest.length > 0) {
    //   payload["attachments"] = rest[0];
    // }

    const response = await transporter.sendMail(payload);

    if (response) {
      return true;
    }
    return false;
  } catch (err) {
    console.log("Getting error while send email:", err);
    logger.error(`Getting error while send email : ${err}`);
    return false;
  }
}

export async function generateEmailVerificationToken(userId) {
  return jwt.sign({ userId }, process.env.JWT_SECRET, { expiresIn: "365d" });
}
