export const fetchUsersWithFilterAndPagination = async (model, options) => {
  const { searchQuery, filter, page = 1, take = 10 } = options;

  try {
    let filterQuery = {};
    if (filter) {
      filterQuery = filter;
    }

    const combinedQuery = { ...searchQuery, ...filterQuery };

    const totalMatchedDocuments = await model.countDocuments(combinedQuery);

    // Ensure page is at least 1
    const maxPage = Math.ceil(totalMatchedDocuments / take);
    const adjustedPage = Math.max(1, Math.min(page, maxPage));

    const skip = (adjustedPage - 1) * take;

    const data = await model
      .find(combinedQuery)
      .sort({ updatedAt: -1 })
      .skip(skip)
      .limit(take);

    const totalPages = Math.ceil(totalMatchedDocuments / take);
    const nextPage = adjustedPage < totalPages ? adjustedPage + 1 : null;
    const prevPage = adjustedPage > 1 ? adjustedPage - 1 : null;

    return {
      data,
      nextPage,
      page: adjustedPage,
      prevPage,
      take: take,
      totalData: totalMatchedDocuments,
      totalPages,
    };
  } catch (error) {
    throw new Error(`Error fetching users: ${error.message}`);
  }
};

export const convertUrlToTitle = (url) => {
  const cleanUrl = url.split("?")[0];
  const parts = cleanUrl.split("/").filter((part) => {
    return !/^[0-9a-fA-F]{24}$/.test(part);
  });

  const formattedTitle = parts
    .map((part) => {
      if (part.includes("-")) {
        return part
          .split("-")
          .map((word) => word.charAt(0).toUpperCase() + word.slice(1))
          .join(" ");
      }
      return part.charAt(0).toUpperCase() + part.slice(1);
    })
    .join(" ");

  return formattedTitle;
};
